@@ -2,7 +2,7 @@
    packageStartupMessage("R/QTLRel is loaded\n")
 }
 .noGenerics <- TRUE
-.onUnload <- function(libpath){
-   library.dynam.unload("QTLRel", libpath)
-}
+#.onUnload <- function(libpath){
+#   library.dynam.unload("QTLRel", libpath)
+#}
 
